# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.intraday.v2 import get_intraday_scalar_pb2 as systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2


class IntradayServiceStub(object):
    """Called to request intraday prices data. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.IntradayScalarStream = channel.unary_stream(
                '/systemathics.apis.services.intraday.v2.IntradayService/IntradayScalarStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayScalarStreamResponse.FromString,
                )
        self.IntradayVectorStream = channel.unary_stream(
                '/systemathics.apis.services.intraday.v2.IntradayService/IntradayVectorStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorStreamResponse.FromString,
                )
        self.IntradayVectorKeyStream = channel.unary_stream(
                '/systemathics.apis.services.intraday.v2.IntradayService/IntradayVectorKeyStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorKeyRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorStreamResponse.FromString,
                )
        self.IntradayFields = channel.unary_unary(
                '/systemathics.apis.services.intraday.v2.IntradayService/IntradayFields',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayFieldsResponse.FromString,
                )
        self.IntradayAssetProviders = channel.unary_unary(
                '/systemathics.apis.services.intraday.v2.IntradayService/IntradayAssetProviders',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayAssetProvidersResponse.FromString,
                )


class IntradayServiceServicer(object):
    """Called to request intraday prices data. 
    """

    def IntradayScalarStream(self, request, context):
        """Gets intraday historical data timeseries by identifier using streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IntradayVectorStream(self, request, context):
        """Gets intraday historical data timeseries by identifier using streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IntradayVectorKeyStream(self, request, context):
        """Gets intraday historical data timeseries by identifier and key using streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IntradayFields(self, request, context):
        """Gets all available fields by asset and provider.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IntradayAssetProviders(self, request, context):
        """Gets all available provider by asset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IntradayServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'IntradayScalarStream': grpc.unary_stream_rpc_method_handler(
                    servicer.IntradayScalarStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayScalarStreamResponse.SerializeToString,
            ),
            'IntradayVectorStream': grpc.unary_stream_rpc_method_handler(
                    servicer.IntradayVectorStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorStreamResponse.SerializeToString,
            ),
            'IntradayVectorKeyStream': grpc.unary_stream_rpc_method_handler(
                    servicer.IntradayVectorKeyStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorKeyRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorStreamResponse.SerializeToString,
            ),
            'IntradayFields': grpc.unary_unary_rpc_method_handler(
                    servicer.IntradayFields,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayFieldsResponse.SerializeToString,
            ),
            'IntradayAssetProviders': grpc.unary_unary_rpc_method_handler(
                    servicer.IntradayAssetProviders,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayAssetProvidersResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.intraday.v2.IntradayService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class IntradayService(object):
    """Called to request intraday prices data. 
    """

    @staticmethod
    def IntradayScalarStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.intraday.v2.IntradayService/IntradayScalarStream',
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayScalarStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IntradayVectorStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.intraday.v2.IntradayService/IntradayVectorStream',
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IntradayVectorKeyStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.intraday.v2.IntradayService/IntradayVectorKeyStream',
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorKeyRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IntradayFields(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.intraday.v2.IntradayService/IntradayFields',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayFieldsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IntradayAssetProviders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.intraday.v2.IntradayService/IntradayAssetProviders',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayAssetProvidersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
