# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v2/set_tick_scalar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v2 import set_data_mode_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_set__data__mode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8systemathics/apis/services/tick/v2/set_tick_scalar.proto\x12\"systemathics.apis.services.tick.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/type/datetime.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x34systemathics/apis/type/shared/v2/set_data_mode.proto\"\xbb\x01\n\x14SetTickScalarRequest\x12K\n\x04info\x18\x01 \x01(\x0b\x32\x35.systemathics.apis.services.tick.v2.SetTickScalarInfoH\x00R\x04info\x12K\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.systemathics.apis.services.tick.v2.SetTickScalarDataH\x00R\x04\x64\x61taB\t\n\x07payload\"~\n\x16\x43learTickScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\"\xbc\x01\n\x11SetTickScalarInfo\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12\x41\n\x04mode\x18\x03 \x01(\x0e\x32-.systemathics.apis.type.shared.v2.SetDataModeR\x04mode\"Z\n\x11SetTickScalarData\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta2\x86\x02\n\x14SetTickScalarService\x12u\n\rSetTickScalar\x12\x38.systemathics.apis.services.tick.v2.SetTickScalarRequest\x1a\x16.google.protobuf.Empty\"\x10\x82\xd3\xe4\x93\x02\n\"\x08/v2/tick(\x01\x12w\n\x0f\x43learTickScalar\x12:.systemathics.apis.services.tick.v2.ClearTickScalarRequest\x1a\x16.google.protobuf.Empty\"\x10\x82\xd3\xe4\x93\x02\n*\x08/v2/tickB\xe9\x01\n&com.systemathics.apis.services.tick.v2B\x12SetTickScalarProtoP\x01\xa2\x02\x04SAST\xaa\x02\"Systemathics.Apis.Services.Tick.V2\xca\x02\"Systemathics\\Apis\\Services\\Tick\\V2\xe2\x02.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\xea\x02&Systemathics::Apis::Services::Tick::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick.v2.set_tick_scalar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.systemathics.apis.services.tick.v2B\022SetTickScalarProtoP\001\242\002\004SAST\252\002\"Systemathics.Apis.Services.Tick.V2\312\002\"Systemathics\\Apis\\Services\\Tick\\V2\342\002.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\352\002&Systemathics::Apis::Services::Tick::V2'
  _globals['_SETTICKSCALARSERVICE'].methods_by_name['SetTickScalar']._options = None
  _globals['_SETTICKSCALARSERVICE'].methods_by_name['SetTickScalar']._serialized_options = b'\202\323\344\223\002\n\"\010/v2/tick'
  _globals['_SETTICKSCALARSERVICE'].methods_by_name['ClearTickScalar']._options = None
  _globals['_SETTICKSCALARSERVICE'].methods_by_name['ClearTickScalar']._serialized_options = b'\202\323\344\223\002\n*\010/v2/tick'
  _globals['_SETTICKSCALARREQUEST']._serialized_start=417
  _globals['_SETTICKSCALARREQUEST']._serialized_end=604
  _globals['_CLEARTICKSCALARREQUEST']._serialized_start=606
  _globals['_CLEARTICKSCALARREQUEST']._serialized_end=732
  _globals['_SETTICKSCALARINFO']._serialized_start=735
  _globals['_SETTICKSCALARINFO']._serialized_end=923
  _globals['_SETTICKSCALARDATA']._serialized_start=925
  _globals['_SETTICKSCALARDATA']._serialized_end=1015
  _globals['_SETTICKSCALARSERVICE']._serialized_start=1018
  _globals['_SETTICKSCALARSERVICE']._serialized_end=1280
# @@protoc_insertion_point(module_scope)
