# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday/v2/set_intraday_scalar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2
from systemathics.apis.type.shared.v2 import set_data_mode_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_set__data__mode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@systemathics/apis/services/intraday/v2/set_intraday_scalar.proto\x12&systemathics.apis.services.intraday.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/type/datetime.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\x1a\x34systemathics/apis/type/shared/v2/set_data_mode.proto\"\xfc\x02\n\x18SetIntradayScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12\x31\n\x08\x64\x61tetime\x18\x03 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12^\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32J.systemathics.apis.services.intraday.v2.SetIntradayScalarRequest.DataEntryR\x04\x64\x61ta\x1a\x37\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xcf\x01\n\x1eSetIntradayScalarStreamRequest\x12M\n\x04info\x18\x01 \x01(\x0b\x32\x37.systemathics.apis.services.intraday.v2.SetIntradayInfoH\x00R\x04info\x12S\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32=.systemathics.apis.services.intraday.v2.SetIntradayScalarDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\x8e\x03\n\x18SetIntradayVectorRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12\x31\n\x08\x64\x61tetime\x18\x03 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x10\n\x03key\x18\x04 \x01(\tR\x03key\x12^\n\x04\x64\x61ta\x18\x05 \x03(\x0b\x32J.systemathics.apis.services.intraday.v2.SetIntradayVectorRequest.DataEntryR\x04\x64\x61ta\x1a\x37\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xcf\x01\n\x1eSetIntradayVectorStreamRequest\x12M\n\x04info\x18\x01 \x01(\x0b\x32\x37.systemathics.apis.services.intraday.v2.SetIntradayInfoH\x00R\x04info\x12S\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32=.systemathics.apis.services.intraday.v2.SetIntradayVectorDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\xf8\x01\n\x1b\x44\x65leteIntradayScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields\x12+\n\x05\x64\x61tes\x18\x04 \x03(\x0b\x32\x15.google.type.DateTimeR\x05\x64\x61tes\"\x92\x02\n\x1b\x44\x65leteIntradayVectorRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields\x12\x45\n\x04keys\x18\x04 \x03(\x0b\x32\x31.systemathics.apis.services.intraday.v2.VectorKeyR\x04keys\"\xbf\x01\n\x0fSetIntradayInfo\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields\"^\n\x15SetIntradayScalarData\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta\"P\n\tVectorKey\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\"p\n\x15SetIntradayVectorData\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x12\n\x04\x64\x61ta\x18\x03 \x03(\x01R\x04\x64\x61ta2\xee\x0b\n\x12SetIntradayService\x12\x8c\x01\n\x13WriteIntradayScalar\x12@.systemathics.apis.services.intraday.v2.SetIntradayScalarRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x13/v2/intraday_scalar\x12\x9a\x01\n\x19WriteIntradayScalarStream\x12\x46.systemathics.apis.services.intraday.v2.SetIntradayScalarStreamRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x13/v2/intraday_scalar(\x01\x12\x8c\x01\n\x13WriteIntradayVector\x12@.systemathics.apis.services.intraday.v2.SetIntradayVectorRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x13/v2/intraday_vector\x12\x9a\x01\n\x19WriteIntradayVectorStream\x12\x46.systemathics.apis.services.intraday.v2.SetIntradayVectorStreamRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x13/v2/intraday_vector(\x01\x12\x8d\x01\n\x14UpdateIntradayScalar\x12@.systemathics.apis.services.intraday.v2.SetIntradayScalarRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\x1a\x13/v2/intraday_scalar\x12\x9b\x01\n\x1aUpdateIntradayScalarStream\x12\x46.systemathics.apis.services.intraday.v2.SetIntradayScalarStreamRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\x1a\x13/v2/intraday_scalar(\x01\x12\x8d\x01\n\x14UpdateIntradayVector\x12@.systemathics.apis.services.intraday.v2.SetIntradayVectorRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\x1a\x13/v2/intraday_vector\x12\x9b\x01\n\x1aUpdateIntradayVectorStream\x12\x46.systemathics.apis.services.intraday.v2.SetIntradayVectorStreamRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\x1a\x13/v2/intraday_vector(\x01\x12\x90\x01\n\x14\x44\x65leteIntradayScalar\x12\x43.systemathics.apis.services.intraday.v2.DeleteIntradayScalarRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15*\x13/v2/intraday_scalar\x12\x90\x01\n\x14\x44\x65leteIntradayVector\x12\x43.systemathics.apis.services.intraday.v2.DeleteIntradayVectorRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15*\x13/v2/intraday_vectorB\x81\x02\n*com.systemathics.apis.services.intraday.v2B\x16SetIntradayScalarProtoP\x01\xa2\x02\x04SASI\xaa\x02&Systemathics.Apis.Services.Intraday.V2\xca\x02&Systemathics\\Apis\\Services\\Intraday\\V2\xe2\x02\x32Systemathics\\Apis\\Services\\Intraday\\V2\\GPBMetadata\xea\x02*Systemathics::Apis::Services::Intraday::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.intraday.v2.set_intraday_scalar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.systemathics.apis.services.intraday.v2B\026SetIntradayScalarProtoP\001\242\002\004SASI\252\002&Systemathics.Apis.Services.Intraday.V2\312\002&Systemathics\\Apis\\Services\\Intraday\\V2\342\0022Systemathics\\Apis\\Services\\Intraday\\V2\\GPBMetadata\352\002*Systemathics::Apis::Services::Intraday::V2'
  _globals['_SETINTRADAYSCALARREQUEST_DATAENTRY']._options = None
  _globals['_SETINTRADAYSCALARREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_SETINTRADAYVECTORREQUEST_DATAENTRY']._options = None
  _globals['_SETINTRADAYVECTORREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayScalar']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayScalar']._serialized_options = b'\202\323\344\223\002\025\"\023/v2/intraday_scalar'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayScalarStream']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayScalarStream']._serialized_options = b'\202\323\344\223\002\025\"\023/v2/intraday_scalar'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayVector']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayVector']._serialized_options = b'\202\323\344\223\002\025\"\023/v2/intraday_vector'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayVectorStream']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayVectorStream']._serialized_options = b'\202\323\344\223\002\025\"\023/v2/intraday_vector'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayScalar']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayScalar']._serialized_options = b'\202\323\344\223\002\025\032\023/v2/intraday_scalar'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayScalarStream']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayScalarStream']._serialized_options = b'\202\323\344\223\002\025\032\023/v2/intraday_scalar'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayVector']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayVector']._serialized_options = b'\202\323\344\223\002\025\032\023/v2/intraday_vector'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayVectorStream']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayVectorStream']._serialized_options = b'\202\323\344\223\002\025\032\023/v2/intraday_vector'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['DeleteIntradayScalar']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['DeleteIntradayScalar']._serialized_options = b'\202\323\344\223\002\025*\023/v2/intraday_scalar'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['DeleteIntradayVector']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['DeleteIntradayVector']._serialized_options = b'\202\323\344\223\002\025*\023/v2/intraday_vector'
  _globals['_SETINTRADAYSCALARREQUEST']._serialized_start=480
  _globals['_SETINTRADAYSCALARREQUEST']._serialized_end=860
  _globals['_SETINTRADAYSCALARREQUEST_DATAENTRY']._serialized_start=805
  _globals['_SETINTRADAYSCALARREQUEST_DATAENTRY']._serialized_end=860
  _globals['_SETINTRADAYSCALARSTREAMREQUEST']._serialized_start=863
  _globals['_SETINTRADAYSCALARSTREAMREQUEST']._serialized_end=1070
  _globals['_SETINTRADAYVECTORREQUEST']._serialized_start=1073
  _globals['_SETINTRADAYVECTORREQUEST']._serialized_end=1471
  _globals['_SETINTRADAYVECTORREQUEST_DATAENTRY']._serialized_start=805
  _globals['_SETINTRADAYVECTORREQUEST_DATAENTRY']._serialized_end=860
  _globals['_SETINTRADAYVECTORSTREAMREQUEST']._serialized_start=1474
  _globals['_SETINTRADAYVECTORSTREAMREQUEST']._serialized_end=1681
  _globals['_DELETEINTRADAYSCALARREQUEST']._serialized_start=1684
  _globals['_DELETEINTRADAYSCALARREQUEST']._serialized_end=1932
  _globals['_DELETEINTRADAYVECTORREQUEST']._serialized_start=1935
  _globals['_DELETEINTRADAYVECTORREQUEST']._serialized_end=2209
  _globals['_SETINTRADAYINFO']._serialized_start=2212
  _globals['_SETINTRADAYINFO']._serialized_end=2403
  _globals['_SETINTRADAYSCALARDATA']._serialized_start=2405
  _globals['_SETINTRADAYSCALARDATA']._serialized_end=2499
  _globals['_VECTORKEY']._serialized_start=2501
  _globals['_VECTORKEY']._serialized_end=2581
  _globals['_SETINTRADAYVECTORDATA']._serialized_start=2583
  _globals['_SETINTRADAYVECTORDATA']._serialized_end=2695
  _globals['_SETINTRADAYSERVICE']._serialized_start=2698
  _globals['_SETINTRADAYSERVICE']._serialized_end=4216
# @@protoc_insertion_point(module_scope)
