# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v2/get_tick_scalar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8systemathics/apis/services/tick/v2/get_tick_scalar.proto\x12\"systemathics.apis.services.tick.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/type/datetime.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xca\x01\n\x11TickScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12O\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\"\xc7\x01\n\x18TickScalarStreamResponse\x12P\n\x04info\x18\x01 \x01(\x0b\x32:.systemathics.apis.services.tick.v2.TickScalarStreamFieldsH\x00R\x04info\x12N\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x38.systemathics.apis.services.tick.v2.TickScalarStreamItemH\x00R\x04\x64\x61taB\t\n\x07payload\"0\n\x16TickScalarStreamFields\x12\x16\n\x06\x66ields\x18\x01 \x03(\tR\x06\x66ields\"]\n\x14TickScalarStreamItem\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta\"~\n\x1fTickScalarAssetProviderResponse\x12[\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32G.systemathics.apis.services.tick.v2.TickScalarAssetProviderItemResponseR\x04\x64\x61ta\"\x8d\x01\n#TickScalarAssetProviderItemResponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\"p\n\x18TickScalarFieldsResponse\x12T\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32@.systemathics.apis.services.tick.v2.TickScalarFieldsItemResponseR\x04\x64\x61ta\"\x9e\x01\n\x1cTickScalarFieldsItemResponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields2\xe1\x03\n\x11TickScalarService\x12\xa3\x01\n\x10TickScalarStream\x12\x35.systemathics.apis.services.tick.v2.TickScalarRequest\x1a<.systemathics.apis.services.tick.v2.TickScalarStreamResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v2/tick_scalar/0\x01\x12\x89\x01\n\x10TickScalarFields\x12\x16.google.protobuf.Empty\x1a<.systemathics.apis.services.tick.v2.TickScalarFieldsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v2/tick_scalar_fields/\x12\x99\x01\n\x17TickScalarAssetProvider\x12\x16.google.protobuf.Empty\x1a\x43.systemathics.apis.services.tick.v2.TickScalarAssetProviderResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v2/tick_scalar_provider/B\xe9\x01\n&com.systemathics.apis.services.tick.v2B\x12GetTickScalarProtoP\x01\xa2\x02\x04SAST\xaa\x02\"Systemathics.Apis.Services.Tick.V2\xca\x02\"Systemathics\\Apis\\Services\\Tick\\V2\xe2\x02.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\xea\x02&Systemathics::Apis::Services::Tick::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick.v2.get_tick_scalar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.systemathics.apis.services.tick.v2B\022GetTickScalarProtoP\001\242\002\004SAST\252\002\"Systemathics.Apis.Services.Tick.V2\312\002\"Systemathics\\Apis\\Services\\Tick\\V2\342\002.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\352\002&Systemathics::Apis::Services::Tick::V2'
  _globals['_TICKSCALARSERVICE'].methods_by_name['TickScalarStream']._options = None
  _globals['_TICKSCALARSERVICE'].methods_by_name['TickScalarStream']._serialized_options = b'\202\323\344\223\002\022\022\020/v2/tick_scalar/'
  _globals['_TICKSCALARSERVICE'].methods_by_name['TickScalarFields']._options = None
  _globals['_TICKSCALARSERVICE'].methods_by_name['TickScalarFields']._serialized_options = b'\202\323\344\223\002\031\022\027/v2/tick_scalar_fields/'
  _globals['_TICKSCALARSERVICE'].methods_by_name['TickScalarAssetProvider']._options = None
  _globals['_TICKSCALARSERVICE'].methods_by_name['TickScalarAssetProvider']._serialized_options = b'\202\323\344\223\002\033\022\031/v2/tick_scalar_provider/'
  _globals['_TICKSCALARREQUEST']._serialized_start=363
  _globals['_TICKSCALARREQUEST']._serialized_end=565
  _globals['_TICKSCALARSTREAMRESPONSE']._serialized_start=568
  _globals['_TICKSCALARSTREAMRESPONSE']._serialized_end=767
  _globals['_TICKSCALARSTREAMFIELDS']._serialized_start=769
  _globals['_TICKSCALARSTREAMFIELDS']._serialized_end=817
  _globals['_TICKSCALARSTREAMITEM']._serialized_start=819
  _globals['_TICKSCALARSTREAMITEM']._serialized_end=912
  _globals['_TICKSCALARASSETPROVIDERRESPONSE']._serialized_start=914
  _globals['_TICKSCALARASSETPROVIDERRESPONSE']._serialized_end=1040
  _globals['_TICKSCALARASSETPROVIDERITEMRESPONSE']._serialized_start=1043
  _globals['_TICKSCALARASSETPROVIDERITEMRESPONSE']._serialized_end=1184
  _globals['_TICKSCALARFIELDSRESPONSE']._serialized_start=1186
  _globals['_TICKSCALARFIELDSRESPONSE']._serialized_end=1298
  _globals['_TICKSCALARFIELDSITEMRESPONSE']._serialized_start=1301
  _globals['_TICKSCALARFIELDSITEMRESPONSE']._serialized_end=1459
  _globals['_TICKSCALARSERVICE']._serialized_start=1462
  _globals['_TICKSCALARSERVICE']._serialized_end=1943
# @@protoc_insertion_point(module_scope)
